﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Configuration;
using System.Data;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Collections.ObjectModel;
using System.Text;

namespace ShapeFileOverGoogleMap
{
    public partial class MapPage : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                GetShapeFile();
            }
        }
        protected void GetShapeFile()
        {
            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
            Map1.MapUnit = GeographyUnit.Meter;

            Map1.MapTools.OverlaySwitcher.Enabled = true;
            Map1.MapTools.MouseCoordinate.Enabled = true;
            GoogleOverlay google = new GoogleOverlay("Google Map");
            google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
            google.GoogleMapType = GoogleMapType.Normal;

            ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer(Server.MapPath("~/ShapeFile/WAGHOLI.shp"));
            shapeFileFeatureLayer.Open();

            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, 212, 220, 184), GeoColor.FromArgb(255, 132, 132, 154), 1);
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            ShapeFileFeatureLayer.BuildIndexFile(shapeFileFeatureLayer.ShapePathFileName);

            Proj4Projection proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(32643);
            proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
            proj4.Open();
            shapeFileFeatureLayer.FeatureSource.Projection = proj4;

            LayerOverlay shapeOverlay = new LayerOverlay();
            shapeOverlay.Layers.Add("ShapeOverlay", shapeFileFeatureLayer);
            shapeOverlay.TransitionEffect = TransitionEffect.None;
            shapeOverlay.IsBaseOverlay = false;
            shapeOverlay.TileType = TileType.SingleTile;
            Map1.CustomOverlays.Add(google);
            Map1.CustomOverlays.Add(shapeOverlay);


            Map1.CurrentExtent = shapeFileFeatureLayer.GetBoundingBox();

            AreaStyle areaSt = new AreaStyle();
            areaSt.OutlinePen.Color = GeoColor.FromArgb(255, 132, 132, 154);
            areaSt.OutlinePen.Width = 1;
            ValueStyle valueStyle = new ValueStyle();
            valueStyle.ColumnName = "LU_TYPE";
            valueStyle.ValueItems.Add(new ValueItem("AGRICULTURE", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 162, 222, 145)))));
            valueStyle.ValueItems.Add(new ValueItem("COMMERCIAL", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 102, 140, 255)))));
            valueStyle.ValueItems.Add(new ValueItem("FOREST", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(130, 38, 153, 0)))));
            valueStyle.ValueItems.Add(new ValueItem("HILLTOP_HILLSLOPE", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 219, 139, 238)))));
            valueStyle.ValueItems.Add(new ValueItem("INDUSTRIAL", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 219, 139, 238)))));
            valueStyle.ValueItems.Add(new ValueItem("PUBLIC SERVICES", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 247, 105, 144)))));
            valueStyle.ValueItems.Add(new ValueItem("PUBLIC UTILITY", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 245, 245, 122)))));
            valueStyle.ValueItems.Add(new ValueItem("RECREATIONAL", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 76, 230, 0)))));
            valueStyle.ValueItems.Add(new ValueItem("RESIDENTIAL", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 245, 245, 122)))));
            valueStyle.ValueItems.Add(new ValueItem("SPECIAL AREAS", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 151, 219, 245)))));
            valueStyle.ValueItems.Add(new ValueItem("TRANSPORT", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 206, 203, 202)))));
            valueStyle.ValueItems.Add(new ValueItem("VACANT", new AreaStyle(new GeoSolidBrush(GeoColor.StandardColors.White))));
            valueStyle.ValueItems.Add(new ValueItem("WATER", new AreaStyle(new GeoSolidBrush(GeoColor.FromArgb(110, 127, 223, 255)))));
            //valueStyle.ValueItems.Add(new ValueItem("HOSPITAL", new AreaStyle(new GeoSolidBrush(GeoColor.StandardColors.Magenta))));
            //shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(valueStyle);
            //shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(areaSt);
        }
    }
}
